OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Navnet er for langt",
    "The given web address is too long" : "Nettadressen er for lang",
    "The given web address is not a valid URL" : "Nettadressen er ikke en gyldig URL",
    "The given legal notice address is too long" : "Adressen for juridiske varsel er for lang",
    "The given legal notice address is not a valid URL" : "Adressen til den juridiske varslingen er ikke en gyldig URL",
    "The given privacy policy address is too long" : "Adressen til personvernerklæringen er for lang ",
    "The given privacy policy address is not a valid URL" : "Addressen til personvernerklæringen er ikke en gyldig url",
    "The given slogan is too long" : "Slagordet er for langt",
    "The given color is invalid" : "Fargen er ugyldig",
    "Disable-user-theming should be true or false" : "Deaktiver-bruker-tema skal være sant eller usant",
    "Saved" : "Lagret",
    "Invalid app given" : "Ugyldig app gitt",
    "Invalid type for setting \"defaultApp\" given" : "Ugyldig type for innstilling \"defaultApp\" gitt",
    "Invalid setting key" : "Ugyldig innstillingsnøkkel",
    "The file was uploaded" : "Filen ble lastet opp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Filen er større enn grensen satt i upload_max_filesize i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Filen du prøvde å laste opp er større enn grensen satt i MAX_FILE_SIZE i HTML-skjemaet",
    "The file was only partially uploaded" : "Filen ble kun delvis nedlastet",
    "No file was uploaded" : "Ingen filer ble lastet opp",
    "Missing a temporary folder" : "Mangler midlertidig mappe",
    "Could not write file to disk" : "Kunne ikke skrive fil til disk",
    "A PHP extension stopped the file upload" : "A PHP-utvidelse stoppet filopplastingen",
    "No file uploaded" : "Ingen fil lastet opp",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Du bruker et tilpasset tema. Innstillinger i app for tilpasning av tema kan bli overskrevet av disse.",
    "Theming" : "Temavalg",
    "Appearance and accessibility" : "Utseende og tilgjengelighet",
    "PHP Imagick module" : "PHP Imagick modul",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP-modulen \"imagick\" er ikke aktivert selv om tema-appen er det. For at favicongenerering skal fungere riktig, må du installere og aktivere denne modulen.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "PHP-modulen \"imagick\" for denne instansen mangler støtte for SVG. For økt kompatibilitet anbefales det å installere den.",
    "Dark theme with high contrast mode" : "Mørkt tema med modus for høy kontrast",
    "Enable dark high contrast mode" : "Aktiver mørkhøykontrastmodus",
    "Similar to the high contrast mode, but with dark colours." : "Ligner på høykontrastmodus, men med mørke farger.",
    "Dark theme" : "Mørkt tema",
    "Enable dark theme" : "Aktiver mørkt tema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Et mørkt tema for å lette øynene dine ved å redusere den generelle lysstyrken og lysstyrken.",
    "System default theme" : "System standardtema",
    "Enable the system default" : "Aktiver systemstandarden",
    "Using the default system appearance." : "Bruker standard systemutseende.",
    "Dyslexia font" : "Dysleksi skrifttype",
    "Enable dyslexia font" : "Aktiver dysleksi skrifttype",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic er en gratis skrifttype egnet for å minske de mest vanligste lesefeilene som dysleksi forårsaker.",
    "High contrast mode" : "Høykontrastmodus",
    "Enable high contrast mode" : "Aktiver høy kontrast",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "En høykontrast modus for å få en lettere navigasjon. Den visuelle kvaliteten vil bli reusert men klarheten vil bli økt.",
    "Light theme" : "Lyst tema",
    "Enable the default light theme" : "Aktiver standard lyst tema",
    "The default light appearance." : "Standard lyst utseende.",
    "Legal notice" : "Juridisk varsel",
    "Privacy policy" : "Personvern",
    "Adjust the Nextcloud theme" : "Tilpass Nextcloud-tema",
    "Name" : "Navn",
    "Web link" : "Nettside lenke",
    "a safe home for all your data" : "et trygt hjem for alle dine data",
    "Slogan" : "Slagord",
    "Primary color" : "Primærfarge",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Primærfargen brukes til å markere elementer som viktige knapper. Det kan bli litt justert avhengig av gjeldende fargeskjema.",
    "Legal notice link" : "Juridisk varslingslenke",
    "Privacy policy link" : "Personvernerklæring",
    "Header logo" : "Header logo",
    "Upload new header logo" : "Last opp ny header logo",
    "Favicon" : "Favoritt ikon",
    "Upload new favicon" : "Last opp nytt ikon",
    "User settings" : "Brukerinnstillinger",
    "Disable user theming" : "Deaktiver brukertema",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Selv om du kan velge og tilpasse forekomsten, kan brukerne endre bakgrunn og farger. Hvis du vil håndheve tilpasningen din, kan du slå på dette.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Temavalg gjør det enkelt å tilpasse utseende og følelsen av din installasjon og støttede klienter. Dette vil bli synlig for alle brukere.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "I stedet for et bakgrunnsbilde kan du også konfigurere en vanlig bakgrunnsfarge. Hvis du bruker et bakgrunnsbilde, vil endring av denne fargen påvirke fargen på ikonene på appmenyen.",
    "Background color" : "Bakgrunnsfarge",
    "Upload new logo" : "Last opp ny logo",
    "Logo" : "Logo",
    "Upload new background and login image" : "Last opp ny bakgrunn- og påloggingsbilde",
    "Background and login image" : "Bakgrunn og påloggingsbilde",
    "Advanced options" : "Avanserte innstillinger",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installer PHP-utvidelsen Imagemagick med støtte for SVG-bilder for å opprette favikoner automatisk basert på opplastet logo og farge.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ikke nøl med å rapportere problemer på {issuetracker}vår problemdatabase{linkend}. Og bli gjerne med i {designteam}vårt designteam{linkend} hvis du vil bidra.",
    "Appearance and accessibility settings" : "Innstilinger for utseende og tilgjengelighet",
    "Misc accessibility options" : "Diverse tilgjengelighetsalternativer",
    "Enable blur background filter (may increase GPU load)" : "Aktiver bakgrunnsfilter for uskarphet (kan øke GPU-belastningen)",
    "Customization has been disabled by your administrator" : "Tilpassing er deaktivert av systemansvarlig",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Angi en primærfarge for å fremheve viktige elementer. Fargen som brukes for elementer som primærknapper, kan variere litt ettersom den blir justert for å oppfylle tilgjengelighetskrav.",
    "Background and color" : "Bakgrunn og farge",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Bakgrunnen kan settes til et bilde fra standardsettet, et egendefinert opplastet bilde eller en vanlig farge.",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "I noen tilfeller kan hurtigtaster forstyrre tilgjengelighetsverktøy. For å tillate fokus på verktøyet ditt riktig, kan du deaktivere alle hurtigtaster her. Dette vil også deaktivere alle tilgjengelige snarveier i apper.",
    "Disable all keyboard shortcuts" : "Deaktiver alle tastatursnarveier",
    "Current selected app: {app}, position {position} of {total}" : "Nåværende valgt app: {app}, posisjon {position} av {total}",
    "Move up" : "Flytt opp",
    "Move down" : "Flytt ned",
    "Select a background from your files" : "Velg en bakgrunn fra filene dine",
    "Select background" : "Velg bakgrunn",
    "No background has been selected" : "Ingen bakgrunn er valgt",
    "Custom background" : "Tilpasset bakgrunn",
    "Plain background" : "Ensfarget bakgrunn",
    "Default background" : "Standard bakgrunn",
    "Theme selection is enforced" : "Temavalg er fremtvunget",
    "Could not set the app order" : "Kunne ikke angi apprekkefølgen",
    "Could not reset the app order" : "Kunne ikke tilbakestille apprekkefølgen",
    "Navigation bar settings" : "Innstillinger for navigasjonsfelt",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Du kan konfigurere apprekkefølgen som brukes for navigasjonsfeltet. Den første oppføringen vil være standardappen, åpnet etter innlogging eller når du klikker på logoen.",
    "The default app can not be changed because it was configured by the administrator." : "Standardappen kan ikke endres fordi den ble konfigurert av administratoren.",
    "The app order was changed, to see it in action you have to reload the page." : "Apprekkefølgen ble endret, for å se den i aksjon må du laste inn siden på nytt.",
    "Reset default app order" : "Tilbakestill standard apprekkefølge",
    "Could not set primary color" : "Kunne ikke angi primærfarge",
    "Reset primary color" : "Tilbakestill primærfarge",
    "Could not set global default apps" : "Kan ikke angi globale standardapper",
    "Default app" : "Standard app",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Standardappen er den appen som f.eks. åpnes etter innlogging eller når logoen i menyen klikkes på.",
    "Use custom default app" : "Bruk tilpasset standardapp",
    "Global default app" : "Global standardapp",
    "Global default apps" : "Globale standardapper",
    "Default app priority" : "Standard appprioritet",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Hvis en app ikke er aktivert for en bruker, brukes den neste appen med lavere prioritet.",
    "Select a custom color" : "Velg en tilpasset farge",
    "Reset to default" : "Tilbakestill til standard",
    "Upload" : "Last opp",
    "Remove background image" : "Fjern bakgrunnsbilde",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universell utforming er viktig for oss. Vi følger web-standarder og tester for full funksjonalitet, både uten mus og med hjelpeprogrammer, slik som skjermlesere. Vi etterstreber å følge {guidelines}Retningslinjer for tilgjengelighet på nettsider{linkend} 2.1 på nivå AA, og med temaet for høy kontrast også nivå AAA."
},
"nplurals=2; plural=(n != 1);");
